import pandas as pd
import pkg_resources

def _load_from_resource(resource_path):
    return pd.read_csv(pkg_resources.resource_filename(__name__,resource_path))

def load_beauty():
    resource_path = '/'.join(('data','beauty.zip'))
    return _load_from_resource(resource_path)

def load_starbucks():
    resource_path = '/'.join(('data','starbucks.zip'))
    return _load_from_resource(resource_path) 

def load_bond():
    resource_path = '/'.join(('data','bond.zip'))
    return _load_from_resource(resource_path) 


def load_movies():
    resource_path = '/'.join(('data','movies.zip'))
    return _load_from_resource(resource_path) 


def load_chopsticks():
    resource_path = '/'.join(('data','chopsticks.zip'))
    return _load_from_resource(resource_path) 


def load_chopsticks_full():
    resource_path = '/'.join(('data','chopsticks_full.zip'))
    return _load_from_resource(resource_path) 


def load_correlation_example():
    resource_path = '/'.join(('data','correlation.zip'))
    return _load_from_resource(resource_path) 





# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['jrpyml', 'jrpyml.datasets']

package_data = \
{'': ['*'], 'jrpyml': ['vignettes/*'], 'jrpyml.datasets': ['data/*']}

install_requires = \
['matplotlib>=3.1,<4.0',
 'numpy>=1.16,<2.0',
 'pandas>=0.24.2,<0.25.0',
 'scipy==1.2',
 'statsmodels>=0.9.0,<0.10.0']

setup_kwargs = {
    'name': 'jrpyml',
    'version': '0.1.2',
    'description': '',
    'long_description': None,
    'author': 'Jamie',
    'author_email': 'jamie@jumpingrivers.com',
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.5,<4.0',
}


setup(**setup_kwargs)
